==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/SummaryRowSectionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryRowDescriptionMetadata } from "./SummaryRowDescriptionMetadata";
import { SummaryRowSectionDescription } from "./SummaryRowSectionDescription";
/**
 * @hidden
 */
export let SummaryRowSectionDescriptionMetadata = /*@__PURE__*/ (() => {
    class SummaryRowSectionDescriptionMetadata extends Base {
        static b(a) {
            if (SummaryRowSectionDescriptionMetadata.a == null) {
                SummaryRowSectionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SummaryRowSectionDescriptionMetadata.c(SummaryRowSectionDescriptionMetadata.a);
            }
            if (a.k(SummaryRowSectionDescriptionMetadata.a)) {
                return;
            }
            a.ab(SummaryRowSectionDescriptionMetadata.a);
        }
        static c(a) {
            SummaryRowDescriptionMetadata.c(a);
        }
        static d(a) {
            SummaryRowSectionDescriptionMetadata.b(a);
            a.ad("SummaryRowSection", () => new SummaryRowSectionDescription());
            a.ac("SummaryRowSection", SummaryRowSectionDescriptionMetadata.a);
        }
    }
    SummaryRowSectionDescriptionMetadata.$t = markType(SummaryRowSectionDescriptionMetadata, 'SummaryRowSectionDescriptionMetadata');
    SummaryRowSectionDescriptionMetadata.a = null;
    return SummaryRowSectionDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/SummaryRowSectionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryRowDescriptionMetadata } from "./SummaryRowDescriptionMetadata";
import { SummaryRowSectionDescription } from "./SummaryRowSectionDescription";
/**
 * @hidden
 */
export let SummaryRowSectionDescriptionMetadata = /*@__PURE__*/ (() => {
    class SummaryRowSectionDescriptionMetadata extends Base {
        static b(a) {
            if (SummaryRowSectionDescriptionMetadata.a == null) {
                SummaryRowSectionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SummaryRowSectionDescriptionMetadata.c(SummaryRowSectionDescriptionMetadata.a);
            }
            if (a.k(SummaryRowSectionDescriptionMetadata.a)) {
                return;
            }
            a.ac(SummaryRowSectionDescriptionMetadata.a);
        }
        static c(a) {
            SummaryRowDescriptionMetadata.c(a);
        }
        static d(a) {
            SummaryRowSectionDescriptionMetadata.b(a);
            a.ae("SummaryRowSection", () => new SummaryRowSectionDescription());
            a.ad("SummaryRowSection", SummaryRowSectionDescriptionMetadata.a);
        }
    }
    SummaryRowSectionDescriptionMetadata.$t = markType(SummaryRowSectionDescriptionMetadata, 'SummaryRowSectionDescriptionMetadata');
    SummaryRowSectionDescriptionMetadata.a = null;
    return SummaryRowSectionDescriptionMetadata;
})();
